import numpy as np
import matplotlib.pyplot as plt
import imageio

# Ejercicio imagen satélite Landsat (Agustín Millares Valenzuela)
# El archivo "LE72000342005001ASN00_B6_VCID_1.tif" contiene la información sin tratar de la banda 6 del
# satélite Landsat 7-ETM. La expresión matemática para convertir la información de partida de número digital, ND, en
# temperatura de brillo o de superficie es
# \begin{equation}
# T(K)=\frac{k2}{ln(\frac{k1}{17.04/254(B6 - 1)})}
# \end{equation}
# donde T(K), es la temperatura en grados Kelvin, k1 = 666.09, k2 = 1282.71 y B6 representa cada valor de la imágen
# obtenida por el satélite. Realiza los siguientes cálculos
# \begin{itemize}
# \item Importa la imagen en python y plantea una ventana de proyecto desde la fila 4000 hasta la 6000 y desde la
#       columna 2000 a la 6000
# \item Convierte la información almacenada como ND en temperatura de brillo o de superficie.
# \item Localiza las zonas con temperatura menor a 10 ^{\circ}$C
# \item Realiza un perfil de temperatura que pase por la mitad del entorno de proyecto
# \end{itemize}

# Abrimos archivo de Landsat correspondiente a la banda 6
Data_B6 = imageio.imread('LE72000342005001ASN00_B6_VCID_1.TIF')

# Vemos los datos iniciales y seleccionamos ventana (si no es muy grande)
r = np.arange(4000, 6000, 1)
c = np.arange(2000, 6000, 1)

# Convertimos los datos a double para poder operar
B6 = np.double(Data_B6[4000:6000, 2000:6000])

# CONVERSIÓN DE LA BANDA 6 A TEMPERATURA
k1 = 666.09
k2 = 1282.71
mask1 = B6 < 0
B6[mask1] = 0
T_Kelvin = k2 / (np.log(k1 / ((17.040) / (255 - 1) * (B6 - 1)) + 1))
T_Grados = T_Kelvin - 273.15

plt.figure('Temperatura (grados)')
plt.imshow(T_Grados, aspect='auto', clim=(0.0, 20))
plt.colorbar()
plt.show()

# Localizamos T< 10
#T_menor_10 = np.zeros((np.size(T_Grados,0), np.size(T_Grados,1)))
# for i in range(0, np.size(T_Grados, 0)):
#    for j in range(0, np.size(T_Grados, 1)):
#        if T_Grados[i, j]<10:
#            T_menor_10[i, j] =  T_Grados[i, j]
#        else:
#            T_menor_10[i, j] = np.nan

# o von máscara
T_menor_10_mask = np.zeros((np.size(T_Grados, 0), np.size(T_Grados, 1)))
mask2 = T_Grados < 10
mask3 = T_Grados >= 10
T_menor_10_mask[mask2] = T_Grados[mask2]
T_menor_10_mask[mask3] = np.nan


plt.figure('Temperatura menor a 10 grados')
plt.imshow(T_menor_10_mask, aspect='auto', clim=(0.0, 10))
plt.colorbar()
plt.show()

plt.figure('perfil de temperatura')
plt.plot(T_Grados[1000, :], 'r')
plt.grid(True)
plt.xlabel('distancia (x 30) metros')
plt.ylabel('Temperatura (grados)')
